#Perform Drug Cascade Analysis
#Last Modified: 08DEC2015
#Giganti

#This file does most of the heavy lifting for this analysis.  It evaluates patient status for drugs and outcomes at all time points throughout 10 years.
#Note that in the analysis stage we looked at many contingencies (90 v 180 day windows, include missing lab patients in figures or extrapolate their lab values based upon observed values, use everyday intervals or 6 month intervals, etc.).  The functions were designed to look at these various contingencies, but sacrificed code readability!

#The following should be run first.

#FirstWave Data Prep (CCASAnet).R generates an analysis dataset
#FirstWaveAnalysisFunctions.R contains functions that will be used in this code


#19SEP2014   We have decided to use the 6 month intervals with 90 day windows. We have deprecated everyday intervals, 180 day windows, and the inclusion of missing labs as a category in the figure.

#Important note:  LTFU for the drug cascade is different from LTFU for the VL cascade
#Here, they are only classified as LTFU if they have a formal LTFU entry in the follow table

#08DEC2015 - We now want to generate figures for both non-naive and naive patients.


#All functions located in one file
source('~/Documents/CCASAnet/FirstWave/FirstWaveAnalysisFunctions.R', chdir = TRUE)
source('~/Documents/CCASAnet/FirstWave/FirstWave Data Prep (CCASAnet).R', chdir = FALSE)
setwd("~/Documents/CCASAnet/FirstWave")

#If we want to rerun the entire analysis, change update from 0 to 1
update<-1



####################
#Drug
####################
#Important note:  LTFU for this drug cascade is different from LTFU for the VL cascade
#In VL cascade, they were LTFU if no measurements greater than 180 days after last VL
#Here, they are only classified as LTFU if they have a formal LTFU entry in the follow table

#Keep patients who are non-naive
Pre2004Cohort<-CCASAnet_Analysis[,c("site.patient","site","FirstHAARTdate")]
#With 10 year window, do not need obs greater than 4000 days
maxtime<-4000
death.short<-merge(Pre2004Cohort,follow[follow$death_y==1,c("site.patient","death_dt")],by="site.patient")
death.short$day<-with(death.short,as.numeric(as.Date(death_dt,origin="1970-01-01")-FirstHAARTdate))
death.short<-death.short[death.short$day<maxtime & is.na(death.short$day)==F,]

censor.short<-merge(follow.short[follow.short$death_y!=1,c("site.patient","censor_dt")],Pre2004Cohort,by=c("site.patient"))
censor.short$day<-with(censor.short,as.numeric(as.Date(censor_dt,origin="1970-01-01")-FirstHAARTdate))
censor.short<-censor.short[censor.short$day<maxtime & is.na(censor.short$day)==F,]


drug.short<-art[,c("site.patient","startdate","enddate","regimen")]
drug.short$regimen<-toupper(drug.short$regimen)
drug.short$regimen<-with(drug.short, as.character(ifelse(regimen=="NNRTI","NNRTI",
ifelse(regimen=="BOOSTED PI","BOOSTED PI",
ifelse(regimen=="3 NRTI","3 NRTI",
ifelse(regimen=="UNBOOSTED PI","UNBOOSTED PI",
ifelse(regimen=="PI","UNBOOSTED PI",
ifelse(regimen=="OTHER","OTHER",
ifelse(regimen %in% c("NONHAART","NON HAART","NON-HAART"),"nonHAART",
NA)))))))))
drug.short.HAART<-merge(drug.short,Pre2004Cohort,by="site.patient")
drug.short.HAART<-with(drug.short.HAART,drug.short.HAART[as.Date(startdate)>=FirstHAARTdate,])
drug.short.HAART$start<-as.numeric(with(drug.short.HAART,startdate-FirstHAARTdate))
drug.short.HAART$end<-as.numeric(with(drug.short.HAART,enddate-FirstHAARTdate))
drug.short.HAART<-with(drug.short.HAART, drug.short.HAART[order(site.patient,startdate,enddate),c("site.patient","start","end","regimen")])


drug.short.HAART$obsnumber<-output.obsnumber(drug.short.HAART)
drug.short.HAART<-drug.short.HAART[drug.short.HAART$start<4000,]

if (update==1){
    regimen.matrix<-drug.matrix<-matrix(NA,nrow(Pre2004Cohort),maxtime)
    
    patid.relevel<-as.factor(as.character(drug.short.HAART$site.patient))
    patid<-as.numeric(patid.relevel)
    
    for (j in 1:dim(drug.short.HAART)[1]){
        regimen.matrix[patid[j],drug.short.HAART$start[j]:min(drug.short.HAART$end[j],maxtime,na.rm=TRUE)] 		<-drug.short.HAART$regimen[j]
        drug.matrix[patid[j],(drug.short.HAART$start[j]):min(drug.short.HAART$end[j],maxtime,na.rm=TRUE)] 		<-paste("Regimen ", drug.short.HAART$obsnumber[j],sep="")
    }
    
    for (j in 1:dim(drug.matrix)[1]){
        if (unique(patid.relevel)[j]%in%death.short$site.patient) {
            regimen.matrix[j,(max(2,death.short[death.short$site.patient==as.character(unique(patid.relevel)[j]),"day"]):maxtime)]<-"Dead"
            drug.matrix[j,(max(2,death.short[death.short$site.patient==as.character(unique(patid.relevel)[j]),"day"]):maxtime)]<-"Dead"
        }
        if (unique(patid.relevel)[j]%in%censor.short$site.patient) {
            regimen.matrix[j,(max(2,censor.short[censor.short$site.patient==as.character(unique(patid.relevel)[j]),"day"]):maxtime)]<-"LTFU"
            drug.matrix[j,(max(2,censor.short[censor.short$site.patient==as.character(unique(patid.relevel)[j]),"day"]):maxtime)]<-"LTFU"
        }
    }
    
    regimen.matrix<-ifelse(is.na(regimen.matrix),"Holiday",regimen.matrix)
    drug.matrix<-ifelse(is.na(drug.matrix),"Holiday",drug.matrix)
    
    
    drug.matrix.updated<-ifelse(drug.matrix!="Dead" & drug.matrix!="LTFU" &  drug.matrix!="Holiday" & drug.matrix!="Regimen 1" & drug.matrix!="Regimen 2" & drug.matrix!="Regimen 3", "Regimen 4+", drug.matrix)
    
    
    save(drug.matrix.updated,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_DrugMatrix.Rda")
    save(regimen.matrix,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_RegimenMatrix.Rda")
    
}

DrugbySite<-function(sitelab,drug.matrix,EveryDay="Yes",RemoveMissing="Drug",Cohort){
    
    drug.matrix.updated<-drug.matrix[Cohort$site==sitelab,]
    
    drug.table<-matrix(NA,dim(drug.matrix.updated)[2],7)
    drug.table[,7]<-apply(drug.matrix.updated=="Dead",2,mean)
    drug.table[,6]<-apply(drug.matrix.updated=="LTFU",2,mean)
    drug.table[,5]<-apply(drug.matrix.updated=="Holiday",2,mean)
    
    drug.table[,4]<-apply(drug.matrix.updated=="Regimen 4+",2,mean)
    drug.table[,3]<-apply(drug.matrix.updated=="Regimen 3",2,mean)
    drug.table[,2]<-apply(drug.matrix.updated=="Regimen 2",2,mean)
    drug.table[,1]<-apply(drug.matrix.updated=="Regimen 1",2,mean)
    
    
    
    areagraph(drug.table,label.drug,"Regimen status",EveryDay=EveryDay,RemoveMissing=RemoveMissing)
    
    
}



load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_DrugMatrix.Rda")

drug.table<-matrix(NA,dim(drug.matrix.updated)[2],7)
drug.table[,7]<-apply(drug.matrix.updated=="Dead",2,mean)
drug.table[,6]<-apply(drug.matrix.updated=="LTFU",2,mean)
drug.table[,5]<-apply(drug.matrix.updated=="Holiday",2,mean)

drug.table[,4]<-apply(drug.matrix.updated=="Regimen 4+",2,mean)
drug.table[,3]<-apply(drug.matrix.updated=="Regimen 3",2,mean)
drug.table[,2]<-apply(drug.matrix.updated=="Regimen 2",2,mean)
drug.table[,1]<-apply(drug.matrix.updated=="Regimen 1",2,mean)



label.drug<-c("Regimen 1", "Regimen 2", "Regimen 3", "Regimen 4+","Interruption","LTFU","Dead")





################################################################################################
################################################################################################

################################################
#Sensitivity Analysis
#Added 18AUG2014
#Restrict analysis to ART-naive patients only
################################################
NaivePre2004Cohort<-Pre2004Cohort[CCASAnet_Analysis$recart_y==0,]


load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_DrugMatrix.Rda")

drug.matrix.naive<-drug.matrix.updated[CCASAnet_Analysis$recart_y==0,]
drug.table.naive<-matrix(NA,dim(drug.matrix.naive)[2],7)
drug.table.naive[,7]<-apply(drug.matrix.naive=="Dead",2,mean)
drug.table.naive[,6]<-apply(drug.matrix.naive=="LTFU",2,mean)
drug.table.naive[,5]<-apply(drug.matrix.naive=="Holiday",2,mean)

drug.table.naive[,4]<-apply(drug.matrix.naive=="Regimen 4+",2,mean)
drug.table.naive[,3]<-apply(drug.matrix.naive=="Regimen 3",2,mean)
drug.table.naive[,2]<-apply(drug.matrix.naive=="Regimen 2",2,mean)
drug.table.naive[,1]<-apply(drug.matrix.naive=="Regimen 1",2,mean)




#08DEC2015
#Include drug cascade for patients who are ART-experieced
#Only do for overall cohort for now

NonnaivePre2004Cohort<-Pre2004Cohort[CCASAnet_Analysis$recart_y!=0,]



drug.matrix.nonnaive<-drug.matrix.updated[CCASAnet_Analysis$recart_y!=0,]
drug.table.nonnaive<-matrix(NA,dim(drug.matrix.nonnaive)[2],7)
drug.table.nonnaive[,7]<-apply(drug.matrix.nonnaive=="Dead",2,sum)
drug.table.nonnaive[,6]<-apply(drug.matrix.nonnaive=="LTFU",2,sum)
drug.table.nonnaive[,5]<-apply(drug.matrix.nonnaive=="Holiday",2,sum)
drug.table.nonnaive[,4]<-apply(drug.matrix.nonnaive=="Regimen 4+",2,sum)
drug.table.nonnaive[,3]<-apply(drug.matrix.nonnaive=="Regimen 3",2,sum)
drug.table.nonnaive[,2]<-apply(drug.matrix.nonnaive=="Regimen 2",2,sum)
drug.table.nonnaive[,1]<-apply(drug.matrix.nonnaive=="Regimen 1",2,sum)
colnames(drug.table.nonnaive)<-c("Regimen 1", "Regimen 2", "Regimen 3", "Regimen 4+","Interruption","LTFU","Dead")









########################################################################################################################
########################################################################################################################
########################################################################################################################
########################################################################################################################


#Generate drug cascade figures for manuscript
require(ggplot2)

#Need to create a new folder for 'Figures' (2016-04-02)
if (dir.exists("Figures")==FALSE)   { dir.create("Figures") }
###


#Legend
pdf("Figures/FirstWave_DrugLegend.pdf")
label.drug2<-c("Regimen 1", "Regimen 2", "Regimen 3", "Regimen 4+","Interruption","     LTFU","Dead")
par(mfrow=c(1,1),mar=c(0,0,0,0))
x<-rnorm(1)
y<-rnorm(1)
plot(x~y,col=0,xlim=c(0,1),ylim=c(0,1),axes=F,xlab="",ylab="")
legend(0,0.9,label.drug2,fill=c("dark green","green", "orange", "red","grey90","grey50","black"),title="",bty="n",horiz=F,ncol=7,cex=0.65,y.intersp=1)
dev.off()




########################################################################################################################
#Tiff files for Drug cascade (naive and non-naive)
########################################################################################################################

#04APR2016 -- Having difficulty generating .tiff files when sourcing through .Rnw.  Just commenting out since outputted figures are PDF versions

#tiff("Figures/FirstWave_Drug.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#areagraph(drug.table,label.drug,"Regimen status",EveryDay="Yes",RemoveMissing="Drug") + theme(text = element_text(size=5), axis.ticks  = element_line(size=0.1))
#dev.off()
###
#tiff("Figures/FirstWave_Drug_argentina.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#DrugbySite("argentina",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
###
#tiff("Figures/FirstWave_Drug_brazil.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#DrugbySite("brazil",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_chile.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("chile",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_haiti.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("haiti",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_honduras.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("honduras",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_mexico.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("mexico",drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()


########################################################################################################################
#PDFs overall and by site (naive and nonnaive cohort)
########################################################################################################################
#PDF files for Drug cascade
pdf("Figures/FirstWave_Drug.pdf")
areagraph(drug.table,label.drug,"Regimen status",EveryDay="Yes",RemoveMissing="Drug")
dev.off()

DrugPlot.bysite<-function(site1){
    pdf(paste("Figures/FirstWave_Drug_",site1,".pdf",sep=""))
    DrugbySite(site1,drug.matrix.updated,Cohort=Pre2004Cohort) + theme(legend.position = "none")
}
DrugPlot.bysite("argentina")
dev.off()
DrugPlot.bysite("brazil")
dev.off()
DrugPlot.bysite("chile")
dev.off()
DrugPlot.bysite("haiti")
dev.off()
DrugPlot.bysite("honduras")
dev.off()
DrugPlot.bysite("mexico")
dev.off()

















########################################################################################################################
#Tiffs overall and by site (naive only cohort)
########################################################################################################################

#04APR2016 -- Having difficulty generating .tiff files when sourcing through .Rnw.  Just commenting out since outputted figures are PDF versions
#tiff("Figures/FirstWave_Drug_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#areagraph(drug.table.naive,label.drug,"Regimen status",EveryDay="Yes",RemoveMissing="Drug")  + theme(text = element_text(size=5), axis.ticks  = element_line(size=0.1))
#dev.off()
###
#tiff("Figures/FirstWave_Drug_argentina_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#DrugbySite("argentina",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
###
#tiff("Figures/FirstWave_Drug_brazil_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = "lzw")
#DrugbySite("brazil",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_chile_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("chile",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_haiti_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("haiti",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_honduras_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("honduras",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()
#tiff("Figures/FirstWave_Drug_mexico_naive.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
#DrugbySite("mexico",drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")+theme(text = element_text(size=5),axis.ticks  = element_line(size=0.1))
#dev.off()



########################################################################################################################
#PDFs overall and by site (naive cohort)
########################################################################################################################
pdf("Figures/FirstWave_Drug_naive.pdf")
areagraph(drug.table.naive,label.drug,"Regimen status",EveryDay="Yes",RemoveMissing="Drug")  + theme(legend.position = "none")
dev.off()


DrugPlotnaive.bysite<-function(site1){
    pdf(paste("Figures/FirstWave_Drug_",site1,"_naive.pdf",sep=""))
    DrugbySite(site1,drug.matrix.naive,Cohort=NaivePre2004Cohort) + theme(legend.position = "none")
}


DrugPlotnaive.bysite("argentina")
dev.off()
DrugPlotnaive.bysite("brazil")
dev.off()
DrugPlotnaive.bysite("chile")
dev.off()
DrugPlotnaive.bysite("haiti")
dev.off()
DrugPlotnaive.bysite("honduras")
dev.off()
DrugPlotnaive.bysite("mexico")
dev.off()





########################################################################################################################
#PDFs overall and by site (nonaive cohort)
#Small sample sizes at most sites for non-naive led to no individual site figures being generated
########################################################################################################################
pdf("Figures/FirstWave_Drug_nonnaive.pdf")
areagraph(drug.table.nonnaive,label.drug,"Regimen status",EveryDay="Yes",RemoveMissing="Drug") + theme(legend.position = "none")
dev.off()


